Picker

Struct Picker 

pub struct Picker<D: SelectDelegate + 'static> { /* private fields */ }
A control for picking from a list of options.

This component wraps gpui-component’s Select (dropdown).

The generic parameter D is the delegate type (e.g., Vec<&'static str>, SearchableVec<String>, etc.) that provides the list of options.

Example

// Create state in your view with Vec as the delegate
let country: Entity<SelectState<Vec<&'static str>>> = cx.new(|cx|
    SelectState::new(
        vec!["USA", "Canada", "UK", "Germany"],
        None,  // No initial selection
        window,
        cx,
    )
);

// Subscribe to changes
cx.subscribe(&country, |this, _, event: &SelectEvent<_>, cx| {
    if let SelectEvent::Confirm(value) = event {
        this.on_country_changed(value);
    }
});

// Use in render
Picker::new(&country)
    .placeholder("Select country...")

Implementations

Source

impl<D: SelectDelegate + 'static> Picker<D>

pub fn new(state: &Entity<SelectState<D>>) -> Self

Create a new picker with the given state.

pub fn placeholder(self, placeholder: impl Into<SharedString>) -> Self

Set the placeholder text.

pub fn cleanable(self, cleanable: bool) -> Self

Show a clear button when an item is selected.

pub fn width(self, width: f32) -> Self

Set the width of the picker.

pub fn disabled(self, disabled: bool) -> Self

Disable the picker.