pub struct Group { /* private fields */ }Expand description
A transparent container that groups views without affecting layout.
Group allows you to apply modifiers to multiple views at once without introducing a new layout container.
Example
ⓘ
Group::new()
.child(Text::new("One"))
.child(Text::new("Two"))
.child(Text::new("Three"))
.foreground_color(Color::red())Implementations
Sourceimpl Group
impl Group
Sourcepub fn child<E: IntoElement>(self, child: E) -> Self
pub fn child<E: IntoElement>(self, child: E) -> Self
Add a child view.
Sourcepub fn children<I, E>(self, children: I) -> Selfwhere
I: IntoIterator<Item = E>,
E: IntoElement,
pub fn children<I, E>(self, children: I) -> Selfwhere
I: IntoIterator<Item = E>,
E: IntoElement,
Add multiple children.