Module prelude

Module prelude 

Convenient imports for Allui users.

Example

use allui::prelude::*;

Re-exports

pub use crate::layout::Alignment;
pub use crate::layout::EmptyView;
pub use crate::layout::ForEach;
pub use crate::layout::Grid;
pub use crate::layout::GridItem;
pub use crate::layout::GridItemSize;
pub use crate::layout::GridRow;
pub use crate::layout::Group;
pub use crate::layout::HStack;
pub use crate::layout::HorizontalAlignment;
pub use crate::layout::If;
pub use crate::layout::IfLet;
pub use crate::layout::LazyHGrid;
pub use crate::layout::LazyHStack;
pub use crate::layout::LazyVGrid;
pub use crate::layout::LazyVStack;
pub use crate::layout::List;
pub use crate::layout::ListStyle;
pub use crate::layout::ScrollAxes;
pub use crate::layout::ScrollView;
pub use crate::layout::Section;
pub use crate::layout::Spacer;
pub use crate::layout::VStack;
pub use crate::layout::VerticalAlignment;
pub use crate::layout::ZStack;
pub use crate::components::Button;
pub use crate::components::ButtonStyle;
pub use crate::components::Divider;
pub use crate::components::Image;
pub use crate::components::Label;
pub use crate::components::ProgressView;
pub use crate::components::ProgressViewStyle;
pub use crate::components::Text;
pub use crate::components::Picker;
pub use crate::components::SecureField;
pub use crate::components::Slider;
pub use crate::components::Stepper;
pub use crate::components::TextEditor;
pub use crate::components::TextField;
pub use crate::components::Toggle;
pub use crate::modifier::ContentMode;
pub use crate::modifier::Frame;
pub use crate::modifier::Modified;
pub use crate::modifier::Modifier;
pub use crate::modifier::Padding;
pub use crate::modifier::Tappable;
pub use crate::types::ClickHandler;
pub use crate::style::Color;
pub use crate::style::Font;
pub use crate::style::FontDesign;
pub use crate::style::FontWeight;
pub use crate::style::SemanticColor;

Structs

IndexPath
Represents an index path in a list, which consists of a section index,
InputState
InputState to keep editing state of the super::Input.
PickerGroup
A group of select items with a title.
PickerState
State of the Select.
SearchableVec
A built-in searchable vector for select items.
SliderState
State of the Slider.
VirtualListScrollHandle
A scroll handle for VirtualList.

Enums

IconName
The name of an icon in the asset bundle.
PickerEvent
Events emitted by the SelectState.
SliderEvent
Events emitted by the SliderState.
SliderValue
The value of the slider, can be a single value or a range of values.
StepAction
StepperEvent

Traits

PickerDelegate
PickerItem
A trait for items that can be displayed in a select.